@@ -16,8 +16,8 @@ KEYS_UP = (curses.KEY_UP, ord("k"))
 KEYS_DOWN = (curses.KEY_DOWN, ord("j"))
 KEYS_SELECT = (curses.KEY_RIGHT, ord(" "))
 
-SYMBOL_CIRCLE_FILLED = "◉"
-SYMBOL_CIRCLE_EMPTY = "◯"
+SYMBOL_CIRCLE_FILLED = "(x)"
+SYMBOL_CIRCLE_EMPTY = "( )"
 
 OPTION_T = TypeVar("OPTION_T", str, Option)
 PICK_RETURN_T = Tuple[OPTION_T, int]
@@ -97,7 +97,7 @@ class Picker(Generic[OPTION_T]):
                     if index in self.selected_indexes
                     else SYMBOL_CIRCLE_EMPTY
                 )
-                prefix = f"{prefix} {symbol} "
+                prefix = f"{prefix} {symbol}"
 
             option_as_str = option.label if isinstance(option, Option) else option
             lines.append(f"{prefix} {option_as_str}")
